@@ -3,7 +3,7 @@ use crate::creds::Credentials;
 use crate::ctx;
 
 use dirs::home_dir;
-use std::path::PathBuf;
+use std::path::{Path, PathBuf};
 use std::process::Command;
 use std::rc::Rc;
 use std::sync::Arc;
@@ -12,33 +12,33 @@ use anyhow::{anyhow, Result};
 use handlebars::Handlebars;
 use once_cell::sync::Lazy;
 use serde_json::json;
-use skim::prelude::{unbounded, Key, SkimOptionsBuilder};
-use skim::{Skim, SkimItemReceiver, SkimItemSender};
+use skim::prelude::{unbounded, Key};
+use skim::{Skim, SkimItemReceiver, SkimItemSender, SkimOptions};
 
-static CREDENTIALS_PATH: Lazy<PathBuf> = Lazy::new(|| {
+pub static CREDENTIALS_PATH: Lazy<PathBuf> = Lazy::new(|| {
     let mut path = home_dir().unwrap();
     path.push(".aws/credentials");
     path
 });
 
 #[derive(Debug)]
-pub struct AWS<'a> {
+pub struct AWS<'a, P: AsRef<Path>> {
     configs: Rc<Configs>,
-    credentials_path: PathBuf,
+    credentials_path: P,
     reg: Handlebars<'a>,
 }
 
-impl AWS<'_> {
-    pub fn new(configs: Rc<Configs>) -> Result<Self> {
+impl<P: AsRef<Path>> AWS<'_, P> {
+    pub fn new(configs: Rc<Configs>, credentials_path: P) -> Result<Self> {
         Ok(Self {
             configs,
-            credentials_path: CREDENTIALS_PATH.clone(),
+            credentials_path,
             reg: Handlebars::new(),
         })
     }
 }
 
-impl ctx::CTX for AWS<'_> {
+impl<P: AsRef<Path>> ctx::CTX for AWS<'_, P> {
     fn auth(&self, profile: &str) -> Result<ctx::Context, ctx::CTXError> {
         let script_template = self.configs.auth_commands.get(profile).ok_or_else(|| {
             ctx::CTXError::NoAuthConfiguration {
@@ -59,11 +59,19 @@ impl ctx::CTX for AWS<'_> {
             .arg("-c")
             .arg(script)
             .status()
-            .map_err(|e| ctx::CTXError::UnexpectedError {
+            .map_err(|e| ctx::CTXError::InvalidConfigurations {
+                message: format!(
+                    "failed to execute an auth script of profile ({}), check configurations",
+                    profile
+                ),
                 source: Some(anyhow!("failed to execute an auth script: {}", e)),
             })?;
         if !status.success() {
-            return Err(ctx::CTXError::UnexpectedError {
+            return Err(ctx::CTXError::InvalidConfigurations {
+                message: format!(
+                    "failed to execute an auth script of profile ({}), check configurations",
+                    profile
+                ),
                 source: Some(anyhow!("failed to run auth script, check output logs")),
             });
         }
@@ -84,14 +92,10 @@ impl ctx::CTX for AWS<'_> {
 
     fn get_active_context(&self) -> Result<ctx::Context, ctx::CTXError> {
         let creds = Credentials::load_credentials(&self.credentials_path)?;
-        let default_profile = creds.list_profiles().into_iter().find(|p| p.default);
-
-        default_profile
-            .map(|p| ctx::Context {
-                name: p.name,
-                active: p.default,
-            })
-            .ok_or(ctx::CTXError::NoActiveContext { source: None })
+        creds.get_default_profile().map(|p| ctx::Context {
+            name: p.name,
+            active: p.default,
+        })
     }
 
     fn use_context(&self, name: &str) -> Result<ctx::Context, ctx::CTXError> {
@@ -104,25 +108,19 @@ impl ctx::CTX for AWS<'_> {
         })
     }
 
-    fn use_context_interactive(&self) -> Result<ctx::Context, ctx::CTXError> {
+    fn use_context_interactive(
+        &self,
+        skim_options: SkimOptions,
+    ) -> Result<ctx::Context, ctx::CTXError> {
         let mut contexts = self.list_contexts()?;
         // skim shows reverse order
         contexts.reverse();
-        let options = SkimOptionsBuilder::default()
-            .height(Some("30%"))
-            .multi(false)
-            .build()
-            .map_err(|err| ctx::CTXError::UnexpectedError {
-                source: Some(anyhow!(err)),
-            })?;
-
         let (tx_item, rx_item): (SkimItemSender, SkimItemReceiver) = unbounded();
         for context in contexts {
             let _ = tx_item.send(Arc::new(context));
         }
         drop(tx_item);
-
-        let selected_items = Skim::run_with(&options, Some(rx_item))
+        let selected_items = Skim::run_with(&skim_options, Some(rx_item))
             .map(|out| match out.final_key {
                 Key::Enter => Ok(out.selected_items),
                 _ => Err(ctx::CTXError::NoContextIsSelected { source: None }),
